@@ -1,10 +1,8 @@
-## ----library, include = FALSE-------------------------------------------------
-library(rlang)
-library(ggstatsplot)
-
 ## ----setup, include = FALSE---------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
+  message = FALSE,
+  warning = FALSE,
   comment = "#>"
 )
 
