@@ -34,7 +34,7 @@ test_that(
     # subtitle
     set.seed(123)
     p_subtitle <-
-      statsExpressions::expr_contingency_tab(
+      statsExpressions::contingency_table(
         data = as.data.frame(Titanic),
         x = "Sex",
         y = "Survived",
@@ -137,33 +137,6 @@ test_that(
   }
 )
 
-# without enough data ---------------------------------------------------------
-
-test_that(
-  desc = "checking if functions work without enough data",
-  code = {
-    skip_on_cran()
-    set.seed(123)
-
-    # creating a dataframe
-    df <- tibble::tribble(
-      ~x, ~y,
-      "one", "one"
-    )
-
-    # should not work
-    expect_s3_class(
-      suppressWarnings(ggbarstats(
-        data = df,
-        x = x,
-        y = y
-      )),
-      "ggplot"
-    )
-  }
-)
-
-
 # expression output --------------------------------------------------
 
 test_that(
@@ -188,7 +161,7 @@ test_that(
 
     set.seed(123)
     stats_output <-
-      statsExpressions::expr_contingency_tab(
+      statsExpressions::contingency_table(
         data = df,
         x = race,
         y = marital,
@@ -210,7 +183,7 @@ test_that(
     # caption output
     set.seed(123)
     p_cap_exp <-
-      statsExpressions::expr_contingency_tab(
+      statsExpressions::contingency_table(
         data = df,
         x = "race",
         y = marital,
